package com.ruoyi.web.controller.tool;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysUser;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tool.domain.TPost;
import com.ruoyi.tool.service.ITPostService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 职位信息Controller
 *
 * @author ruoyi
 * @date 2024-06-13
 */
@RestController
@RequestMapping("/tool/post")
public class TPostController extends BaseController {
    @Autowired
    private ITPostService tPostService;

    /**
     * 查询职位信息列表
     */
    @PreAuthorize("@ss.hasPermi('tool:post:list')")
    @GetMapping("/list")
    public TableDataInfo list(TPost tPost) {
        startPage();
        List<TPost> list = tPostService.selectTPostList(tPost);
        return getDataTable(list);
    }

    /**
     * 导出职位信息列表
     */
    @PreAuthorize("@ss.hasPermi('tool:post:export')")
    @Log(title = "职位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TPost tPost) {
        List<TPost> list = tPostService.selectTPostList(tPost);
        ExcelUtil<TPost> util = new ExcelUtil<TPost>(TPost.class);
        util.exportExcel(response, list, "职位信息数据");
    }

    /**
     * 获取职位信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('tool:post:query')")
    @GetMapping(value = "/{postId}")
    public AjaxResult getInfo(@PathVariable("postId") Long postId) {
        return success(tPostService.selectTPostByPostId(postId));
    }

    /**
     * 新增职位信息
     */
    @PreAuthorize("@ss.hasPermi('tool:post:add')")
    @Log(title = "职位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TPost tPost) {
        return toAjax(tPostService.insertTPost(tPost));
    }

    /**
     * 修改职位信息
     */
    @PreAuthorize("@ss.hasPermi('tool:post:edit')")
    @Log(title = "职位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TPost tPost) {
        return toAjax(tPostService.updateTPost(tPost));
    }

    /**
     * 删除职位信息
     */
    @PreAuthorize("@ss.hasPermi('tool:post:remove')")
    @Log(title = "职位信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{postIds}")
    public AjaxResult remove(@PathVariable Long[] postIds) {
        return toAjax(tPostService.deleteTPostByPostIds(postIds));
    }

    @Log(title = "职位信息", businessType = BusinessType.IMPORT)
    @PreAuthorize("@ss.hasPermi('tool:post:import')")
    @PostMapping("/importData")
    public AjaxResult importData(MultipartFile file) throws Exception {
        ExcelUtil<TPost> util = new ExcelUtil<TPost>(TPost.class);
        List<TPost> userList = util.importExcel(file.getInputStream());
        String operName = getUsername();
        String message = tPostService.importPost(userList, operName);
        return success(message);
    }
}
